// score:100
// alternative dp solution, based on the fact that at most 2 B mice are relevant
// O(n + B^3)
#include <bits/stdc++.h>
using namespace std;

constexpr int inf = 1e9;
template<typename T>
void xmin(T&a, T const&b){
    a = min(a, b);
}
int cdiv(int a, int b){
    assert(0 < b);
    if(a > 0) return (a + b-1)/b;
    return a/b;
}
struct Greedy_Decomp{
    Greedy_Decomp(int A_, int B_) : A(A_), B(B_), U(2*A*B+1), pre(U, {-1, -1}){
        for(int i=0; i <= min(B-1, U/A); ++i){
            for(int j=0; j <= U/B; ++j){
                const int r = i*A + j*B;
                if(r < U){
                    pre[r] = make_pair(i, j);
                }
            }
        }
        assert(pre[U-1].first != -1);
        for(int i=U-1; i>=0; --i){
            if(pre[i].first == -1) pre[i] = pre[i+1];
        }
    }
    pair<int, int> decompose(int x) const {
        return pre[x];
    }
    int A, B, U;
    vector<pair<int, int> > pre;
};
struct Mouse{
    int a, b;
    int hunger;
};
signed main(){
    cin.tie(0);
    ios_base::sync_with_stdio(false);
    int n, A, B;
    cin >> n >> A >> B;
    Greedy_Decomp greed(A, B);
    vector<int> v(n);
    int64_t whole = 0;
    for(auto &e:v) {
        cin >> e;
        if(e > 2*A*B){
            int x = e/(A*B)-1;
            e -= x*A*B;
            whole += x;
        }
    }
    // start with greed solution
    vector<Mouse> mice(n);
    for(int i=0; i<n; ++i){
        auto [a,b] = greed.decompose(v[i]);
        mice[i].hunger = v[i];
        mice[i].a = a;
        mice[i].b = b;
    }
    vector<Mouse> used_mice;
    if(n <= 2*B){
        used_mice.swap(mice); // use all mice
    } else {
        // use B mice with largest number of A-slices
        nth_element(mice.begin(), mice.begin()+B, mice.end(), [](Mouse const&x, Mouse const&y){return x.a > y.a;});
        used_mice.insert(used_mice.end(), mice.begin(), mice.begin()+B);
        mice.erase(mice.begin(), mice.begin()+B);

        // use B mice with largest number of A-slices
        nth_element(mice.begin(), mice.begin()+B, mice.end(), [](Mouse const&x, Mouse const&y){return x.b > y.b;});
        used_mice.insert(used_mice.end(), mice.begin(), mice.begin()+B);
        mice.erase(mice.begin(), mice.begin()+B);
    }
    // now run 70p dp on the 2B best mice
    const int k = used_mice.size();
    vector<vector<int64_t> > dp(k+1, vector<int64_t>(B, inf));
    dp[0][0] = 0;
    for(int i=0; i<k; ++i){
        const int e = used_mice[i].hunger;
        for(int a=0; a <= min(B, e/A+1); ++a){
            const int b = (max(0, e-a*A)+B-1)/B;
            for(int x = 0; x < B-a; ++x){
                xmin(dp[i+1][x+a], dp[i][x]+b);
            }
            // whole pizza of A-slices -> whole pizza of B-slices
            for(int x = B-a; x < B; ++x){
                xmin(dp[i+1][x+a-B], dp[i][x]+b + A);
            }
        }
    }
    // run greedy on other mice
    int total_a = 0, total_b = 0;
    for(auto const&e:mice){
        total_a+=e.a;
        total_b+=e.b;
    }
    
    int ans = inf;
    for(int i=0; i<B; ++i){
        xmin(ans, cdiv(total_b + dp[k][i], A) + cdiv(total_a + i, B));
    }
    cout << whole+ans << "\n";
}
