// score: 95
// very fast dp solution
// O(n B + A B^2)
#include <bits/stdc++.h>
using namespace std;

constexpr int64_t inf = 1e18;

pair<int, int>& operator+=(pair<int, int> &a, pair<int, int> const&b){
    a.first += b.first;
    a.second += b.second;
    return a;
}
pair<int, int> operator+(pair<int, int> a, pair<int, int> const&b){
    a+=b;
    return a;
}
int64_t cdiv(int64_t a, int64_t b){
    assert(0 < b);
    if(a > 0) return (a + b-1)/b;
    return a/b;
}
template<typename T>
bool xmin(T&a, T const&b){
    if(b < a){
        a = b;
        return true;
    } else {
        return false;
    }
};

struct Max{
    Max(int U_) : U(U_), top(0), cnt(2*U+1, 0){
        cnt[0] = 1;
    }
    void up(int x, int v){
        x+=U;
        cnt[x] += v;
        if(v > 0){
            if(x > top) top = x;
            else if(!cnt[top]) {
                // only do this if v > 0, as we might do a v=-1
                // and then a v=+1, in which case we should not move top.
                while(!cnt[top]) --top;
            }
        }
    }
    int get(){
        return top - U;
    }
    int U;
    int top;
    vector<int> cnt;  
};
struct Decomp{
    Decomp(int A_, int B_) : A(A_), B(B_), U(2*A*B+1), pre(U, {-1, -1}), up(U){
        for(int i=0; i <= min(B-1, U/A); ++i){
            for(int j=0; j <= U/B; ++j){
                const int r = i*A + j*B;
                if(r < U){
                    pre[r] = make_pair(i, j);
                }
            }
        }
        assert(pre[U-1].first != -1);
        for(int i=U-1; i>=0; --i){
            if(pre[i].first == -1) up[i] = up[i+1];
            else up[i] = i;
        }
    }
    pair<int, int> operator()(int x) const {
        if(x > 2*A*B){
            int a = max(0, x / (A*B)-1);
            return operator()(x - a*A*B) + make_pair(0, a*A);
        }
        auto ret = pre[up[x]];
        assert(ret.first != -1);
        return ret;
    }
    int A, B, U;
    vector<pair<int, int> > pre;
    vector<int> up;
};

signed main(){
    // start with greed
    int n, A, B;
    cin >> n >> A >> B;
    Decomp de(A, B);
    vector<int> v(n);
    for(auto &e:v) cin >> e;
    pair<int64_t, int64_t> cnt;
    for(auto const&e:v){
        auto tmp = de(e);
        cnt.first += tmp.first;
        cnt.second += tmp.second;
    }
    int64_t ans = cdiv(cnt.first, B) + cdiv(cnt.second, A);
    // do improvement dp
    vector<int> dp(B, 0); // previous dp
    auto dp2 = dp; // next dp
    vector<Max> change(B, Max(2*A)); // DS to quickly check if we have an improvement
    auto do_from = [&](int i, int x){
        for(int j=0; j<i; ++j){
            // to avoid getting the same improvement twice,
            // we go from previous to next dp.
            change[j-i+B].up(dp2[j]-dp[i]-A, x);
        }
        for(int j=i+1; j<B; ++j){
            change[j-i].up(dp2[j]-dp[i], x);
        }
    };
    auto do_to = [&](int i, int x){
        for(int j=0; j<i; ++j){
            change[i-j].up(dp2[i]-dp[j], x);
        }
        for(int j=i+1; j<B; ++j){
            change[i-j+B].up(dp2[i]-dp[j]-A, x);
        }
    };
    for(int i=0; i<B; ++i){
        do_to(i, 1);
    }
    for(auto const&e:v){
        auto start = de(e);
        // try different decompositions in As and Bs.
        for(int a=0; a<= min(B-1, e/A+1); ++a){
            const int b = cdiv(max(0, e-a*A), B);
            int da = a - start.first, db = b - start.second;
            if(da < 0){
                da += B;
                db -= A;
            }
            assert(0 <= da && da < B);
            if(db < change[da].get()){
                bool did = false;
                for(int i=0; i<B-da; ++i){
                    const int j = i+da;
                    if(dp2[j] > dp[i] + db){
                        do_to(j, -1);
                        dp2[j] = dp[i] + db;
                        do_to(j, 1);
                        did = true;
                    }
                }
                for(int i=B-da; i<B; ++i){
                    const int j = i+da-B;
                    if(dp2[j] > dp[i] + db + A){
                        do_to(j, -1);
                        dp2[j] = dp[i] + db + A;
                        do_to(j, 1);
                        did = true;
                    }
                }
                assert(did);
            }
        }
        for(int i=0; i<B; ++i){
            assert(dp2[i] <= dp[i]);
            if(dp2[i] < dp[i]){
                do_from(i, -1);
                dp[i] = dp2[i];
                do_from(i, 1);
            }
        }
    }
    for(int i=0; i<B; ++i){
        xmin(ans, cdiv(cnt.first+i, B)+cdiv(cnt.second+dp[i], A));
    }
    cout << ans << "\n";
}
